inputTemplate property
Input template where you specify placeholders that will be filled with the
values of the keys from InputPathsMap to customize the data
sent to the target. Enclose each InputPathsMaps value in
brackets: <value> The InputTemplate must be valid JSON.
If InputTemplate is a JSON object (surrounded by curly braces),
the following restrictions apply:
- The placeholder cannot be used as an object key.
- Object values cannot include quote marks.
InputPathsMap
and InputTemplate.
"InputTransformer":
{
"InputPathsMap": {"instance": "$.detail.instance","status":
"$.detail.status"},
"InputTemplate": "<instance> is in state <status>"
}
To have the InputTemplate include quote marks within a JSON
string, escape each quote marks with a slash, as in the following example:
"InputTransformer":
{
"InputPathsMap": {"instance": "$.detail.instance","status":
"$.detail.status"},
"InputTemplate": "<instance> is in state
"<status>""
}
Implementation
final String inputTemplate;